        function getT(rr,cc){
       if(rr==1 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260530 a 00</strong> UTC HH+228 (rango:216-240)<br><strong>control +<br>EPS</strong>';}
       if(rr==1 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260530 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>1</strong> representante: <strong>45</strong> miembros: 15 <br>8,10,11,13,22,27,31,33,35,37,38,40,41,44,45';}
       if(rr==1 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260530 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>2</strong> representante: <strong>48</strong> miembros: 14 <br>7,9,12,16,17,18,21,25,26,34,39,43,48,50';}
       if(rr==1 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260530 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>3</strong> representante: <strong>5</strong> miembros: 14 <br>1,2,4,5,15,19,23,28,29,30,36,42,46,49';}
       if(rr==1 && cc==4){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260530 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>4</strong> representante: <strong>47</strong> miembros: 8 <strong>control</strong><br>0,3,6,14,20,24,32,47';}
       if(rr==8 && cc==0){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260530 a 00</strong> UTC HH+228 (rango:216-240)<br><strong>control +<br>EPS</strong>';}
       if(rr==8 && cc==1){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260530 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>1</strong> representante: <strong>45</strong> miembros: 15 <br>8,10,11,13,22,27,31,33,35,37,38,40,41,44,45';}
       if(rr==8 && cc==2){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260530 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>2</strong> representante: <strong>48</strong> miembros: 14 <br>7,9,12,16,17,18,21,25,26,34,39,43,48,50';}
       if(rr==8 && cc==3){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260530 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>3</strong> representante: <strong>5</strong> miembros: 14 <br>1,2,4,5,15,19,23,28,29,30,36,42,46,49';}
       if(rr==8 && cc==4){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260530 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>4</strong> representante: <strong>47</strong> miembros: 8 <strong>control</strong><br>0,3,6,14,20,24,32,47';}
       if(rr==18 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260530 a 00</strong> UTC HH+228 (rango:216-240)<br><strong>control +<br>EPS</strong>';}
       if(rr==18 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260530 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>1</strong> representante: <strong>45</strong> miembros: 15 <br>8,10,11,13,22,27,31,33,35,37,38,40,41,44,45';}
       if(rr==18 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260530 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>2</strong> representante: <strong>48</strong> miembros: 14 <br>7,9,12,16,17,18,21,25,26,34,39,43,48,50';}
       if(rr==18 && cc==3){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260530 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>3</strong> representante: <strong>5</strong> miembros: 14 <br>1,2,4,5,15,19,23,28,29,30,36,42,46,49';}
       if(rr==18 && cc==4){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260530 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>4</strong> representante: <strong>47</strong> miembros: 8 <strong>control</strong><br>0,3,6,14,20,24,32,47';}
       if(rr==24 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260530 a 00</strong> UTC HH+228 (rango:216-240)<br><strong>control +<br>EPS</strong>';}
       if(rr==24 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260530 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>1</strong> representante: <strong>45</strong> miembros: 15 <br>8,10,11,13,22,27,31,33,35,37,38,40,41,44,45';}
       if(rr==24 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260530 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>2</strong> representante: <strong>48</strong> miembros: 14 <br>7,9,12,16,17,18,21,25,26,34,39,43,48,50';}
       if(rr==24 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260530 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>3</strong> representante: <strong>5</strong> miembros: 14 <br>1,2,4,5,15,19,23,28,29,30,36,42,46,49';}
       if(rr==24 && cc==4){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260530 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>4</strong> representante: <strong>47</strong> miembros: 8 <strong>control</strong><br>0,3,6,14,20,24,32,47';}
       if(rr==44 && cc==0){return '<strong>Desviacion estandar e isohipsas de altura geopotencial (m) en 500 hPa</strong><br><br><strong>20260530 a 00</strong> UTC HH+228 (rango:216-240)<br><strong>control +<br>EPS</strong>';}
       if(rr==44 && cc==1){return '<strong>Desviacion estandar e isohipsas de altura geopotencial (m) en 500 hPa</strong><br><br><strong>20260530 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>1</strong> representante: <strong>45</strong> miembros: 15 <br>8,10,11,13,22,27,31,33,35,37,38,40,41,44,45';}
       if(rr==44 && cc==2){return '<strong>Desviacion estandar e isohipsas de altura geopotencial (m) en 500 hPa</strong><br><br><strong>20260530 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>2</strong> representante: <strong>48</strong> miembros: 14 <br>7,9,12,16,17,18,21,25,26,34,39,43,48,50';}
       if(rr==44 && cc==3){return '<strong>Desviacion estandar e isohipsas de altura geopotencial (m) en 500 hPa</strong><br><br><strong>20260530 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>3</strong> representante: <strong>5</strong> miembros: 14 <br>1,2,4,5,15,19,23,28,29,30,36,42,46,49';}
       if(rr==44 && cc==4){return '<strong>Desviacion estandar e isohipsas de altura geopotencial (m) en 500 hPa</strong><br><br><strong>20260530 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>4</strong> representante: <strong>47</strong> miembros: 8 <strong>control</strong><br>0,3,6,14,20,24,32,47';}
       if(rr==45 && cc==0){return '<strong>Spaguetti de presion en superficie (hPa)</strong><br><br><strong>20260530 a 00</strong> UTC HH+228 (rango:216-240)<br><strong>control +<br>EPS</strong>';}
       if(rr==45 && cc==1){return '<strong>Spaguetti de presion en superficie (hPa)</strong><br><br><strong>20260530 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>1</strong> representante: <strong>45</strong> miembros: 15 <br>8,10,11,13,22,27,31,33,35,37,38,40,41,44,45';}
       if(rr==45 && cc==2){return '<strong>Spaguetti de presion en superficie (hPa)</strong><br><br><strong>20260530 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>2</strong> representante: <strong>48</strong> miembros: 14 <br>7,9,12,16,17,18,21,25,26,34,39,43,48,50';}
       if(rr==45 && cc==3){return '<strong>Spaguetti de presion en superficie (hPa)</strong><br><br><strong>20260530 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>3</strong> representante: <strong>5</strong> miembros: 14 <br>1,2,4,5,15,19,23,28,29,30,36,42,46,49';}
       if(rr==45 && cc==4){return '<strong>Spaguetti de presion en superficie (hPa)</strong><br><br><strong>20260530 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>4</strong> representante: <strong>47</strong> miembros: 8 <strong>control</strong><br>0,3,6,14,20,24,32,47';}
}
