        function getT(rr,cc){
       if(rr==5 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260530 a 00</strong> UTC HH+228 (rango:216-240)<br><strong>control +<br>EPS</strong>';}
       if(rr==5 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260530 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>1</strong> representante: <strong>45</strong> miembros: 15 <br>8,10,11,13,22,27,31,33,35,37,38,40,41,44,45';}
       if(rr==5 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260530 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>2</strong> representante: <strong>48</strong> miembros: 14 <br>7,9,12,16,17,18,21,25,26,34,39,43,48,50';}
       if(rr==5 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260530 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>3</strong> representante: <strong>5</strong> miembros: 14 <br>1,2,4,5,15,19,23,28,29,30,36,42,46,49';}
       if(rr==5 && cc==4){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260530 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>4</strong> representante: <strong>47</strong> miembros: 8 <strong>control</strong><br>0,3,6,14,20,24,32,47';}
       if(rr==40 && cc==0){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260530 a 00</strong> UTC HH+228 (rango:216-240)<br><strong>control +<br>EPS</strong>';}
       if(rr==40 && cc==1){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260530 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>1</strong> representante: <strong>45</strong> miembros: 15 <br>8,10,11,13,22,27,31,33,35,37,38,40,41,44,45';}
       if(rr==40 && cc==2){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260530 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>2</strong> representante: <strong>48</strong> miembros: 14 <br>7,9,12,16,17,18,21,25,26,34,39,43,48,50';}
       if(rr==40 && cc==3){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260530 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>3</strong> representante: <strong>5</strong> miembros: 14 <br>1,2,4,5,15,19,23,28,29,30,36,42,46,49';}
       if(rr==40 && cc==4){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260530 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>4</strong> representante: <strong>47</strong> miembros: 8 <strong>control</strong><br>0,3,6,14,20,24,32,47';}
       if(rr==41 && cc==0){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260530 a 00</strong> UTC HH+228 (rango:216-240)<br><strong>control +<br>EPS</strong>';}
       if(rr==41 && cc==1){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260530 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>1</strong> representante: <strong>45</strong> miembros: 15 <br>8,10,11,13,22,27,31,33,35,37,38,40,41,44,45';}
       if(rr==41 && cc==2){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260530 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>2</strong> representante: <strong>48</strong> miembros: 14 <br>7,9,12,16,17,18,21,25,26,34,39,43,48,50';}
       if(rr==41 && cc==3){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260530 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>3</strong> representante: <strong>5</strong> miembros: 14 <br>1,2,4,5,15,19,23,28,29,30,36,42,46,49';}
       if(rr==41 && cc==4){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260530 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>4</strong> representante: <strong>47</strong> miembros: 8 <strong>control</strong><br>0,3,6,14,20,24,32,47';}
       if(rr==42 && cc==0){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260530 a 00</strong> UTC HH+228 (rango:216-240)<br><strong>control +<br>EPS</strong>';}
       if(rr==42 && cc==1){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260530 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>1</strong> representante: <strong>45</strong> miembros: 15 <br>8,10,11,13,22,27,31,33,35,37,38,40,41,44,45';}
       if(rr==42 && cc==2){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260530 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>2</strong> representante: <strong>48</strong> miembros: 14 <br>7,9,12,16,17,18,21,25,26,34,39,43,48,50';}
       if(rr==42 && cc==3){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260530 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>3</strong> representante: <strong>5</strong> miembros: 14 <br>1,2,4,5,15,19,23,28,29,30,36,42,46,49';}
       if(rr==42 && cc==4){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260530 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>4</strong> representante: <strong>47</strong> miembros: 8 <strong>control</strong><br>0,3,6,14,20,24,32,47';}
       if(rr==43 && cc==0){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260530 a 00</strong> UTC HH+228 (rango:216-240)<br><strong>control +<br>EPS</strong>';}
       if(rr==43 && cc==1){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260530 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>1</strong> representante: <strong>45</strong> miembros: 15 <br>8,10,11,13,22,27,31,33,35,37,38,40,41,44,45';}
       if(rr==43 && cc==2){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260530 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>2</strong> representante: <strong>48</strong> miembros: 14 <br>7,9,12,16,17,18,21,25,26,34,39,43,48,50';}
       if(rr==43 && cc==3){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260530 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>3</strong> representante: <strong>5</strong> miembros: 14 <br>1,2,4,5,15,19,23,28,29,30,36,42,46,49';}
       if(rr==43 && cc==4){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260530 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>4</strong> representante: <strong>47</strong> miembros: 8 <strong>control</strong><br>0,3,6,14,20,24,32,47';}
}
